# combo - content management system
# Copyright (C) 2015-2018  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json

from django.conf import settings
from django.core import serializers
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jsonfield import JSONField
from combo.data.fields import RichTextField


class PwaSettings(models.Model):
    offline_text = RichTextField(
            verbose_name=_('Offline Information Text'),
            default=_('You are currently offline.'),
            config_name='small')
    offline_retry_button = models.BooleanField(_('Include Retry Button'), default=True)
    last_update_timestamp = models.DateTimeField(auto_now=True)

    @classmethod
    def singleton(cls):
        return cls.objects.first() or cls()

    @classmethod
    def export_for_json(cls):
        obj = cls.singleton()
        if not obj.id:
            return {}
        serialized_settings = json.loads(serializers.serialize('json', [obj]))
        return serialized_settings[0].get('fields')

    @classmethod
    def load_serialized_settings(cls, json_settings):
        if not json_settings:
            return

        obj = cls.singleton()
        for attr in json_settings:
            setattr(obj, attr, json_settings[attr])
        obj.save()


class PushSubscription(models.Model):
    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE)
    subscription_info = JSONField()
    creation_timestamp = models.DateTimeField(auto_now_add=True)
